@@ -34,23 +34,35 @@ def get_compressed_files(ioargs):
         from pandas.compat import get_lzma_file
         return get_lzma_file()(handle, mode=mode)
     elif compression == 'zip':
+        from zipfile import ZipFile
+
         from pandas.io.common import _BytesZipFile
 
-        handle = _BytesZipFile(handle, mode)
-        if handle.mode == "r":
-            zip_names = handle.namelist()
+        def get_handle(h):
+            innerhandle = _BytesZipFile(h, mode)
+            return innerhandle.buffer if hasattr(innerhandle, 'buffer') else innerhandle
+
+        _handle = get_handle(handle)
+        if _handle.mode == "r":
+            zip_names = _handle.namelist()
 
             if len(zip_names) == 0:
-                raise ValueError(f'Empty ZIP file "{ioargs.filepath_or_buffer}"')
-            return [handle.open(name) for name in zip_names]
-    raise NotImplementedError(f'Unable to process "{handle}" with compressiong method "{compression}"!')
+                raise FileNotFoundError(f'Empty ZIP file "{ioargs.filepath_or_buffer}"')
+            for name in zip_names:
+                if not _handle.fp:
+                    _handle = ZipFile(_handle.filename, mode=mode)
+                yield _handle.open(name)
+            if _handle.fp:
+                _handle.close()
+            return
+    raise NotImplementedError(f'Unable to process "{handle}" with compression method "{compression}"!')
 
 
 def pandas_to_instancelib(dataset, data_cols, label_cols, label_map=None):
     env = il.pandas_to_env(dataset, data_cols, label_cols)
     if label_map is not None:
         if isinstance(label_map, dict):
-            label_map = {str(k): v for k, v in label_map.items()}
+            label_map = {str(k): v for k, v in sorted(label_map.items())}
         env = rename_labels(env, label_map)
     return env
 
@@ -121,7 +133,8 @@ def import_data(dataset,
 
     # Unpack archived file
     extensions = pd.io.common._compression_to_extension.values() if hasattr(pd.io.common, '_compression_to_extension') \
-        else pd.io.common.extension_to_compression.keys()
+        else (pd.io.common._extension_to_compression.keys() if hasattr(pd.io.common, '_extension_to_compression') else \
+              pd.io.common.extension_to_compression.keys())
     if file_type in extensions:
         ioargs = pd.io.common._get_filepath_or_buffer(dataset, compression=file_type.replace('.', ''))
         info(f'Unpacking file "{dataset}".')
