@@ -5,8 +5,7 @@ from typing import Dict, Optional, Union
 
 from instancelib.environment.base import Environment
 from instancelib.instances.base import InstanceProvider
-from instancelib.machinelearning import (AbstractClassifier,
-                                         SkLearnDataClassifier)
+from instancelib.machinelearning import AbstractClassifier, SkLearnDataClassifier
 from instancelib.typehints import LT
 from sklearn.base import is_classifier
 from sklearn.exceptions import NotFittedError
@@ -63,6 +62,7 @@ def import_model(model,
 
     Examples:
         Make a scikit-learn text classifier and train it on SST2
+
         >>> from genbase import import_data, import_model
         >>> from datasets import load_dataset
         >>> ds = import_data(load_dataset('glue', 'sst2'), data_cols='sentence', label_cols='label')
@@ -75,6 +75,7 @@ def import_model(model,
 
         Load a pretrained ONNX model downloaded from 
             https://github.com/mpbron/instancelib-onnx/blob/main/example_models/data-model.onnx
+
         >>> from genbase import import_model
         >>> import_model('data-model.onnx', label_map={0: 'Bedrijfsnieuws', 1: 'Games', 2: 'Smartphones'})
 
@@ -105,7 +106,8 @@ def import_model(model,
         if file_type == '.pkl':
             import pickle  # nosec
             info('Unpickling model (warning: be sure you trust a source before unpickling a model!)')
-            model = pickle.load(model)  # nosec
+            with open(model, 'rb') as f:
+                model = pickle.load(f)  # nosec
         elif file_type == '.onnx':
             if not package_available('ilonnx'):
                 raise ImportError('To import ONNX files install `instancelib-onnx`!')
@@ -149,6 +151,8 @@ def import_model(model,
                 return SkLearnDataClassifier.build_from_model(model, classes=classes)
             else:
                 raise NotImplementedError('Only classifiers are currently supported!')
+    elif isinstance(model, AbstractClassifier):
+        return model
     elif 'torch' in str(type(model)):
         raise ImportError('Convert your PyTorch model with ONNX (https://pytorch.org/docs/stable/onnx.html)' +
                           ' before importing it with instancelib-onnx.')
