@@ -35,7 +35,8 @@ def plotly_available() -> bool:
 
 class ExpressPlot:
     def __init__(self, df: pd.DataFrame, px_fn: Callable, *args, **kwargs):
-        self.plot = px_fn(df, *args, **kwargs)
+        template = kwargs.pop('template', 'none')
+        self.plot = px_fn(df, *args, template=template, **kwargs)
 
     @property
     def static(self):
@@ -45,6 +46,14 @@ class ExpressPlot:
     def interactive(self) -> str:
         return self._repr_html_()
 
+    def update_layout(self, **kwargs) -> 'ExpressPlot':
+        self.plot.update_layout(**kwargs)
+        return self
+
+    def update_traces(self, **kwargs) -> 'ExpressPlot':
+        self.plot.update_traces(**kwargs)
+        return self
+
     def to_html(self, **kwargs) -> str:
         return pio.to_html(self.plot, **kwargs)
 
